@@ -10,11 +10,10 @@ from .tdx2csv import txt2csv
 
 
 @click.command(help=u'通达信数据转换程序.')
-@click.option('-i', '--infile', type=click.Path(exists=True), help='历史数据下载目录, 默认当前目录下 input')
-@click.option('-o', '--output', type=click.Path(exists=True), help='转换后输出目录, 默认当前目录下 output')
+@click.option('-i', '--infile', required=True, type=click.Path(), help='历史数据下载目录, 默认当前目录下 input')
+@click.option('-o', '--output', type=click.Path(), help='转换后输出目录, 默认当前目录下 output')
 def main(infile, output):
-    files = glob1(infile, '*.txt')
-    [txt2csv(Path(infile, txt), output) for txt in tqdm(files)]
+    [txt2csv(Path(infile, txt), Path(output, txt.replace('.txt', '.csv'))) for txt in tqdm(glob1(infile, '*.txt'))]
     return 0
 
 
