@@ -8,7 +8,7 @@ def txt2csv(infile, output=None):
     :param output: 转换后的目标 csv 文件路径
     """
     names = ['date', 'open', 'high', 'low', 'close', 'volume', 'amount']
-    df = pd.read_csv(infile, names=names, header=2, skipfooter=1, index_col='date')
+    df = pd.read_csv(infile, names=names, header=2, skipfooter=1, index_col='date', engine='python')
     bool(output) and df.to_csv(output)
 
     return df
