@@ -3,11 +3,9 @@
 """Tests for `tdx2csv` package."""
 
 import pytest
-
 from click.testing import CliRunner
 
-from tdx2csv import tdx2csv
-from tdx2csv import __main__ as cli
+from tdx2csv.__main__ import main
 
 
 @pytest.fixture
@@ -29,9 +27,7 @@ def test_content(response):
 def test_command_line_interface():
     """Test the CLI."""
     runner = CliRunner()
-    result = runner.invoke(cli.main)
+    result = runner.invoke(main, ['--help'])
+
     assert result.exit_code == 0
-    assert 'tdx2csv.cli.main' in result.output
-    help_result = runner.invoke(cli.main, ['--help'])
-    assert help_result.exit_code == 0
-    assert '--help  Show this message and exit.' in help_result.output
+    assert 'Show this message and exit.' in result.output
